---
title: <span class="badge object-type-scalar"></span> Inch
---
# <span class="badge object-type-scalar"></span> Inch

Length: inch (in)

## Definition

```python
# Length: inch (in)
Inch: typing.Literal["lengthin"] = "lengthin"
```
